import numpy as np
import matplotlib.pyplot as plt

##############################################
####### load tracked clouds budget data ######
##############################################
resultpath         = '../budget_tracked_clouds/'
data               = np.load(resultpath+'conditional_avg_w_budget_cld_lifetime.npz')
w_pstep_plt        = data['w_pstep_plt']
w_pbstep_plt       = data['w_pbstep_plt']
w_pdstep_plt       = data['w_pdstep_plt']
w_buoy_plt         = data['w_buoy_plt']
hgt                = data['hgt']
tot_num_5min       = data['tot_num_5min']
tot_num_15min      = data['tot_num_15min']
tot_num_25min      = data['tot_num_25min']
tot_num_long       = data['tot_num_long']

####################################
plot_labels = ['(a)', '(b)', '(c)', '(d)']
life_labels = ['< 5 min', '5-15 min', '15-25 min', '> 25 min']
obj_num     = [tot_num_5min, tot_num_15min, tot_num_25min, tot_num_long]

nrow = 2
ncol = 2
fig, axs = plt.subplots(nrows=nrow, ncols=ncol,figsize=[10,32])
lines = []

for num_plt in range(0, len(plot_labels)):

    i = int(num_plt/nrow)
    j = int(num_plt%nrow)
    ax = axs[i,j]
    if num_plt == 0:
        ax.plot(np.zeros(w_pstep_plt[num_plt,:].shape),hgt,'-k',linewidth=2.5)
        lines += ax.plot(w_pstep_plt[num_plt,:],hgt,'-b',linewidth=1.5,label='$pgf$')
        lines += ax.plot(w_buoy_plt[num_plt,:],hgt,'-r',linewidth=1.5,label='$buoy$')
        lines += ax.plot(w_pbstep_plt[num_plt,:],hgt,'-.b',linewidth=1.5,label='$pbgf$')
        lines += ax.plot(w_pdstep_plt[num_plt,:],hgt,':b',linewidth=1.5,label='$pdgf$')
    else:
        ax.plot(np.zeros(w_pstep_plt[num_plt,:].shape),hgt,'-k',linewidth=2.5)
        ax.plot(w_pstep_plt[num_plt,:],hgt,'-b',linewidth=1.5,label='$pgf$')
        ax.plot(w_buoy_plt[num_plt,:],hgt,'-r',linewidth=1.5,label='$buoy$')
        ax.plot(w_pbstep_plt[num_plt,:],hgt,'-.b',linewidth=1.5,label='$pbgf$')
        ax.plot(w_pdstep_plt[num_plt,:],hgt,':b',linewidth=1.5,label='$pdgf$')

    ax.set_xlim([-0.015, 0.015])  
    ax.set_ylim([0, 2000])
    ax.set_xticks([-0.015,-0.01,-0.005,0,0.005,0.01,0.015])
    ax.set_yticks([0,250,500,750,1000,1250,1500,1750,2000])
    ax.tick_params(axis='both', which='both', labelsize=15)
    ax.ticklabel_format(style='sci',axis='x',scilimits=(0,0),useOffset=True)
    ax.text(-0.014, 1800, plot_labels[num_plt], fontsize=15)
    ax.set_title(life_labels[num_plt]+ '('+str(obj_num[num_plt])+')', fontsize=15)
    ax.grid(True)
    if num_plt == 0 or num_plt == 2:
        ax.set_ylabel('Height (m)', fontsize=15)

    if num_plt == 2 or num_plt == 3:
        ax.set_xlabel('w tendency $(m s^{-2})$', fontsize=15)

    if num_plt == 0 or num_plt == 1:
       ax.xaxis.set_ticklabels([])
    if num_plt == 1 or num_plt == 3:
       ax.yaxis.set_ticklabels([])

    if num_plt == 1 or num_plt == 3:
        ax2=ax.twinx()
        ax2.set_ylim([0, 2000])
        ax2.set_yticks([0, 500, 1000, 1500, 2000])
        ax2.set_yticklabels(['0', '$z_b$', '$2z_b$', '$3z_b$', '$4z_b$'],fontsize=15)

labels = ['PGF', 'BUOY', 'PBGF', 'PDGF']

fig.subplots_adjust(right=0.8)
plt.legend(lines, labels, bbox_to_anchor=(1.15, 1.1), loc='center left', borderaxespad=0., fontsize=15)
####################################
plt.show()



