import numpy as np
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec


##############################################
####### load tracked clouds budget data ######
##############################################
resultpath  = '../budget_tracked_clouds/'

##############################################
############## Plot section ##################
##############################################

time_s = 0
time_e = 1

hs = 22
he = -1

cld_list=[1, 92, 222]
for time_num in range(time_s, time_e):

    for cld_id in cld_list:

        if cld_id == 1:
           data = np.load(resultpath+'w_budget_cld_1.npz')
        elif cld_id == 92:
           data = np.load(resultpath+'w_budget_cld_92.npz')
        elif cld_id == 222:
           data = np.load(resultpath+'w_budget_cld_222.npz')

        w_pstep_plt   = data['w_pstep_plt']
        w_pbstep_plt  = data['w_pbstep_plt']
        w_pdstep_plt  = data['w_pdstep_plt']
        w_buoy_plt    = data['w_buoy_plt']
        hgt           = data['hgt']

        ################################
        ####################################

        if cld_id == 1: 

            fig = plt.figure(figsize=[6,12])
            gs = gridspec.GridSpec(2, 1)
            gs.update(wspace=0.5)
            ax1 = plt.subplot(gs[0:2,0], )
            plt.plot(np.zeros(w_pstep_plt.shape)[hs:he],hgt[hs:he],'-k',linewidth=2.5)
            plt.plot(w_pstep_plt[hs:he],hgt[hs:he],'-b',linewidth=1.5,label='$PGF$')
            plt.plot(w_buoy_plt[hs:he],hgt[hs:he],'-r',linewidth=1.5,label='$BUOY$')
            plt.plot(w_pbstep_plt[hs:he],hgt[hs:he],'-.b',linewidth=1.5,label='$PBGF$')
            plt.plot(w_pdstep_plt[hs:he],hgt[hs:he],':b',linewidth=1.5,label='$PDGF$')
            plt.legend( loc = 4, fontsize=18)
            axes = plt.gca()
            axes.set_xlim([-0.015, 0.015])
            axes.set_ylim([0, 2000])
            plt.xticks(fontsize=18)
            plt.yticks(fontsize=18)
            axes.ticklabel_format(style='sci',axis='x',scilimits=(0,0),useOffset=True)
            plt.text(-0.013, 1900, '(a)', fontsize=20)
            plt.xlabel('w tendency $(m s^{-2})$',fontsize=18)
            plt.ylabel('Height (m)',fontsize=18)
            plt.title('Cloud '+str(cld_id)+' ('+str(16)+' min)',fontsize=18)
            plt.grid(True)

            ax2=ax1.twinx()                                                                                                                                                                  
            ax2.set_ylim([0, 2000])
            ax2.set_yticks([0, 500, 1000, 1500, 2000])
            ax2.set_yticklabels(['0', '$z_b$', '$2z_b$', '$3z_b$', '$4z_b$'],fontsize=18)

        elif cld_id == 92:

            fig = plt.figure(figsize=[6,12])
            gs = gridspec.GridSpec(2, 1)
            gs.update(wspace=0.5)
            ax1 = plt.subplot(gs[0:2,0], )
            plt.plot(np.zeros(w_pstep_plt.shape)[hs:he],hgt[hs:he],'-k',linewidth=2.5)
            plt.plot(w_pstep_plt[hs:he],hgt[hs:he],'-b',linewidth=1.5,label='$PGF$')
            plt.plot(w_buoy_plt[hs:he],hgt[hs:he],'-r',linewidth=1.5,label='$BUOY$')
            plt.plot(w_pbstep_plt[hs:he],hgt[hs:he],'-.b',linewidth=1.5,label='$PBGF$')
            plt.plot(w_pdstep_plt[hs:he],hgt[hs:he],':b',linewidth=1.5,label='$PDGF$')
            axes = plt.gca()
            axes.set_xlim([-0.015, 0.015])
            axes.set_ylim([0, 2000])
            plt.xticks(fontsize=18)
            plt.yticks(fontsize=18)
            axes.ticklabel_format(style='sci',axis='x',scilimits=(0,0),useOffset=True)
            plt.text(-0.013, 1900, '(b)', fontsize=20)
            plt.xlabel('w tendency $(m s^{-2})$',fontsize=18)
            plt.ylabel('Height (m)',fontsize=18)
            plt.title('Cloud '+str(cld_id)+' ('+str(32)+' min)',fontsize=18)
            plt.grid(True)        

            ax2=ax1.twinx() 
            ax2.set_ylim([0, 2000])
            ax2.set_yticks([0, 500, 1000, 1500, 2000])
            ax2.set_yticklabels(['0', '$z_b$', '$2z_b$', '$3z_b$', '$4z_b$'],fontsize=18)


        elif cld_id == 222:

            fig= plt.figure(figsize=[6, 12])
            gs = gridspec.GridSpec(2, 1)
            gs.update(wspace=0.5)
            ax1 = plt.subplot(gs[0:2,0], )
            plt.plot(np.zeros(w_pstep_plt.shape)[hs:he],hgt[hs:he],'-k',linewidth=2.5)
            plt.plot(w_pstep_plt[hs:he],hgt[hs:he],'-b',linewidth=1.5,label='$PGF$')
            plt.plot(w_buoy_plt[hs:he],hgt[hs:he],'-r',linewidth=1.5,label='$BUOY$')
            plt.plot(w_pbstep_plt[hs:he],hgt[hs:he],'-.b',linewidth=1.5,label='$PBGF$')
            plt.plot(w_pdstep_plt[hs:he],hgt[hs:he],':b',linewidth=1.5,label='$PDGF$')
            axes = plt.gca()
            axes.set_xlim([-0.015, 0.015])
            axes.set_ylim([0, 2000])
            plt.xticks(fontsize=18)
            plt.yticks(fontsize=18)
            axes.ticklabel_format(style='sci',axis='x',scilimits=(0,0),useOffset=True)
            plt.text(-0.013, 1900, '(c)', fontsize=20)
            plt.xlabel('w tendency $(m s^{-2})$',fontsize=18)
            plt.ylabel('Height (m)',fontsize=18)
            plt.title('Cloud '+str(cld_id)+' ('+str(46)+' min)',fontsize=18)
            plt.grid(True)

            ax2=ax1.twinx()
            ax2.set_ylim([0, 2000])
            ax2.set_yticks([0, 500, 1000, 1500, 2000])
            ax2.set_yticklabels(['0', '$z_b$', '$2z_b$', '$3z_b$', '$4z_b$'],fontsize=18)

######
plt.show()




