import numpy as np
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec


##############################################
###### load tracked cloud structure data #####
##############################################
resultpath   = '../cloud_structure/'

data         = np.load(resultpath+'vertical_cross_section.npz')
 
xz_x         = data['xz_x']
xz_z         = data['xz_z']
cld_flg_ver  = data['cld_flg_ver']
ql_ver       = data['ql_ver']
w_buoy_ver   = data['w_buoy_ver']
ww_ver       = data['ww_ver']
p_ver        = data['p_ver']
pd_ver       = data['pd_ver']
w_pstep_ver  = data['w_pstep_ver']
vorh_ver     = data['vorh_ver']
xlim_s       = data['xlim_s']
xlim_e       = data['xlim_e']

###########
v_w      = [-3.0, -2.5, -2.0, -1.5, -1.0, -0.5, 0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5]
v_pdstep = [-0.3,-0.25,-0.2,-0.15, -0.1, -0.06, -0.02, -0.01, 0.01, 0.02, 0.06, 0.1, 0.15, 0.2, 0.25, 0.3]
v_pd     = [-18, -16, -14, -12, -10, -8, -6, -5, -4, -3, -2, -1, -0.6, 0.6, 1, 2, 3, 4, 5, 6, 8, 10, 12, 14, 16, 18]
v_nvor   = [-0.2, -0.15, -0.1, -0.08, -0.06, -0.05, -0.04, -0.03, -0.02, -0.01, -0.005, -0.003, -0.001]

#######################################################################
fig = plt.figure(figsize=[7,16])
gs = gridspec.GridSpec(2, 1)
gs.update(wspace=0.5)

ax1 = plt.subplot(gs[0:2,0], )
plt.contourf(xz_x,xz_z,cld_flg_ver,[-0.5, 0.5, 1.5],colors = ('w','r'),lw=0)
CS1 = ax1.contour(xz_x,xz_z,w_buoy_ver,v_pdstep,colors='b')
ax1.clabel(CS1, fontsize=12, inline = 1)
plt.text((xlim_s+0.1)*1000, 1900, '(a)', fontsize=20)
plt.title('$B$ ($m\ s^{-2}$)', fontsize=16)
axes = plt.gca()
axes.set_ylim([0,2000])
axes.set_xlim([xlim_s*1000,xlim_e*1000])
axes.tick_params(axis='both', which='major', labelsize=14)
plt.xlabel('$X$ (m)', fontsize=14)
plt.ylabel('$Z$ (m)', fontsize=14)

#####
fig = plt.figure(figsize=[7,16])
gs = gridspec.GridSpec(2, 1)
gs.update(wspace=0.5)

ax2 = plt.subplot(gs[0:2,0], )
plt.contourf(xz_x,xz_z,cld_flg_ver,[-0.5, 0.5, 1.5],colors = ('w','r'),lw=0)
CS1 = ax2.contour(xz_x,xz_z,ww_ver,v_w,colors='b')
ax2.clabel(CS1, fontsize=12, inline = 1)
plt.text((xlim_s+0.1)*1000, 1900, '(b)', fontsize=20)
plt.title('$w$ ($m\ s^{-1}$)', fontsize=16)
axes = plt.gca()
axes.set_ylim([0,2000])
axes.set_xlim([xlim_s*1000,xlim_e*1000])
axes.tick_params(axis='both', which='major', labelsize=16)
plt.xlabel('$X$ (m)', fontsize=14)
plt.ylabel('$Z$ (m)', fontsize=14)


#####
fig = plt.figure(figsize=[7,16])
gs = gridspec.GridSpec(2, 1)
gs.update(wspace=0.5)

ax3 = plt.subplot(gs[0:2,0], )
plt.contourf(xz_x,xz_z,cld_flg_ver,[-0.5, 0.5, 1.5],colors = ('w','r'),lw=0)
CS1 = ax3.contour(xz_x,xz_z,p_ver,v_pd,colors=('b'))
ax3.clabel(CS1, fontsize=12, inline = 1)
plt.text((xlim_s+0.1)*1000, 1900, '(c)', fontsize=20)
plt.title('$P$ ($Pa$)', fontsize=16)
axes = plt.gca()
axes.set_ylim([0,2000])
axes.set_xlim([xlim_s*1000,xlim_e*1000])
axes.tick_params(axis='both', which='major', labelsize=14)
plt.xlabel('$X$ (m)', fontsize=14)
plt.ylabel('$Z$ (m)', fontsize=14)


#####
fig = plt.figure(figsize=[7,16])
gs = gridspec.GridSpec(2, 1)
gs.update(wspace=0.5)

ax4 = plt.subplot(gs[0:2,0], )
plt.contourf(xz_x,xz_z,cld_flg_ver,[-0.5, 0.5, 1.5],colors = ('w','r'),lw=0)
CS1 = ax4.contour(xz_x,xz_z,w_pstep_ver,v_pdstep,colors='b')
ax4.clabel(CS1, fontsize=12, inline = 1)
plt.text((xlim_s+0.1)*1000, 1900, '(d)', fontsize=20)
plt.title('$PGF$ ($m\ s^{-2}$)', fontsize=16)
axes = plt.gca()
axes.set_ylim([0,2000])
axes.set_xlim([xlim_s*1000,xlim_e*1000])
axes.tick_params(axis='both', which='major', labelsize=14)
plt.xlabel('$X$ (m)', fontsize=14)
plt.ylabel('$Z$ (m)', fontsize=14)

#######

######
fig = plt.figure(figsize=[7,16])
gs = gridspec.GridSpec(2, 1)
gs.update(wspace=0.5)

ax1 = plt.subplot(gs[0:2,0], )
plt.contourf(xz_x,xz_z,cld_flg_ver,[-0.5, 0.5, 1.5],colors = ('w','r'),lw=0)
CS1 = ax1.contour(xz_x[10::,:],xz_z[10::,:],-vorh_ver[10::,:],v_nvor,colors='b')
ax1.clabel(CS1, fontsize=12, inline = 1)
plt.text((xlim_s+0.1)*1000, 1900, '(e)', fontsize=20)
plt.title('$-\\frac{1}{2}|\\omega|^{2}$ ($s^{-2}$)', fontsize=16)
axes = plt.gca()
axes.set_ylim([0,2000])
axes.set_xlim([xlim_s*1000,xlim_e*1000])
axes.tick_params(axis='both', which='major', labelsize=14)
plt.xlabel('$X$ (m)', fontsize=14)
plt.ylabel('$Z$ (m)', fontsize=14)

######
fig = plt.figure(figsize=[7,16])
gs = gridspec.GridSpec(2, 1)
gs.update(wspace=0.5)

ax2 = plt.subplot(gs[0:2,0], )
plt.contourf(xz_x,xz_z,cld_flg_ver,[-0.5, 0.5, 1.5],colors = ('w','r'),lw=0)
CS1 = ax2.contour(xz_x,xz_z,pd_ver,v_pd,colors='b')
ax2.clabel(CS1, fontsize=12, inline = 1)
plt.text((xlim_s+0.1)*1000, 1900, '(f)', fontsize=20)
plt.title('$PD$ ($Pa$)', fontsize=16)
axes = plt.gca()
axes.set_ylim([0,2000])
axes.set_xlim([xlim_s*1000,xlim_e*1000])
axes.tick_params(axis='both', which='major', labelsize=14)
plt.xlabel('$X$ (m)', fontsize=14)
plt.ylabel('$Z$ (m)', fontsize=14)


###
plt.show()
