import os
import numpy as np
import matplotlib.pyplot as plt

###############################################
################ Plot section #################
###############################################

kk_list = [6, 10, 18]
nstep = 12
xplt  = np.arange(-nstep, nstep+1)

fig, ax = plt.subplots(nrows=1, ncols=3, figsize=[25,15])

##############################################################

for kk in kk_list:

    if kk == 6:
       data           =  np.load('../cloud_structure/normalized_structure_600m.npz') 
    elif kk == 10:
       data           =  np.load('../cloud_structure/normalized_structure_1000m.npz') 
    elif kk == 18:
       data           =  np.load('../cloud_structure/normalized_structure_1800m.npz') 

    thetav_p_comp  =  data['thetav_p']
    ww_comp        =  data['ww_p']
    ql_comp        =  data['ql_p']
    rh_comp        =  data['rh_p']
    hgt            =  data['hgt']
    num_slice      =  data['num_slice_array']

    ####
    if kk == 6:

        plt.subplot(1,3,1)
        plt.plot(xplt, thetav_p_comp, '-r', linewidth = 1.5, label='$\\theta_v^\prime$')
        plt.plot(xplt, rh_comp, '-b', linewidth = 1.5, label='$RH$')
        plt.plot(xplt, ww_comp, '-k', linewidth = 1.5, label='$w^\prime$')
        plt.plot(xplt, ql_comp, linestyle='-', color=(0.5, 0.5, 0.5), linewidth = 1.5, label='$q_l^\prime$')
        plt.plot(xplt, np.zeros((len(xplt))), '--k')
        plt.legend(loc=0)
        plt.ylabel('Normalized vars')
        plt.xlabel('Distance from Center')
        plt.title(str(hgt[kk]+12.5)+' m ('+str(num_slice)+' slices)')
        axes = plt.gca()
        axes.set_ylim([-1.0, 1.2])
        axes.set_xlim([-12, 12])
        axes.set_xticks([-12, -8, -4, 0, 4, 8, 12])
        axes.set_xticklabels(['-1.5 L', '-L', '-0.5 L', 'C', '0.5 L', 'L', '1.5 L'])

    elif kk == 10:  

        plt.subplot(1,3,2)
        plt.plot(xplt, thetav_p_comp, '-r', linewidth = 1.5, label='$\\theta_v^\prime$')
        plt.plot(xplt, rh_comp, '-b', linewidth = 1.5, label='$RH$')
        plt.plot(xplt, ww_comp, '-k', linewidth = 1.5, label='$w^\prime$')
        plt.plot(xplt, ql_comp, linestyle='-', color=(0.5, 0.5, 0.5), linewidth = 1.5, label='$q_l^\prime$')
        plt.plot(xplt, np.zeros((len(xplt))), '--k')
        plt.legend(loc=0)
        plt.xlabel('Distance from Center')
        plt.title(str(hgt[kk]+12.5)+' m ('+str(num_slice)+' slices)')
        axes = plt.gca()
        axes.set_ylim([-1.0, 1.2])
        axes.set_xlim([-12, 12])
        axes.set_xticks([-12, -8, -4, 0, 4, 8, 12])
        axes.set_xticklabels(['-1.5 L', '-L', '-0.5 L', 'C', '0.5 L', 'L', '1.5 L'])

    elif kk == 18:

        plt.subplot(1,3,3)
        plt.plot(xplt, thetav_p_comp, '-r', linewidth = 1.5, label='$\\theta_v^\prime$')
        plt.plot(xplt, rh_comp, '-b', linewidth = 1.5, label='$RH$')
        plt.plot(xplt, ww_comp, '-k', linewidth = 1.5, label='$w^\prime$')
        plt.plot(xplt, ql_comp, linestyle='-', color=(0.5, 0.5, 0.5), linewidth = 1.5, label='$q_l^\prime$')
        plt.plot(xplt, np.zeros((len(xplt))), '--k')
        plt.legend(loc=0)
        plt.xlabel('Distance from center')
        plt.title(str(hgt[kk]+12.5)+' m ('+str(num_slice)+' slices)')
        axes = plt.gca()
        axes.set_ylim([-1.0, 1.2])
        axes.set_xlim([-12, 12])
        axes.set_xticks([-12, -8, -4, 0, 4, 8, 12])
        axes.set_xticklabels(['-1.5 L', '-L', '-0.5 L', 'C', '0.5 L', 'L', '1.5 L'])

####################################################

plt.show()


